@@ -36,3 +36,27 @@ cat fwanalog.opts.master \
 	| sed 's!@inputfiles_dir@!/var/log!' \
 	> fwanalog.opts.solarisipf
 
+cat fwanalog.opts.master \
+	| sed 's!@logformat@!zynos!' \
+	| sed 's!@inputfiles_mask@!router*!' \
+	| sed 's!@inputfiles_dir@!/var/log!' \
+	> fwanalog.opts.zynos
+
+cat fwanalog.opts.master \
+	| sed 's!@logformat@!pix!' \
+	| sed 's!@inputfiles_mask@!firewall*!' \
+	| sed 's!@inputfiles_dir@!/var/log!' \
+	> fwanalog.opts.pix
+
+cat fwanalog.opts.master \
+	| sed 's!@logformat@!watchguard!' \
+	| sed 's!@inputfiles_mask@!firewall*!' \
+	| sed 's!@inputfiles_dir@!/var/log!' \
+	> fwanalog.opts.watchguard
+
+cat fwanalog.opts.master \
+	| sed 's!@logformat@!fw1!' \
+	| sed 's!@inputfiles_mask@!firewall*!' \
+	| sed 's!@inputfiles_dir@!/var/log!' \
+	> fwanalog.opts.fw1
+
